"""
ai_api_unified version module.

Edit the string below *and* the `version` field in pyproject.toml together
each time you cut a new release.
"""

from __future__ import annotations

__all__: list[str] = ["__version__"]

__version__: str = "0.1.2"
